@@ -7,6 +7,7 @@ os.environ['PANDA_URL_SSL'] = 'https://ai-idds-01.cern.ch:25443/server/panda'
 
 from pandatools import Client  # noqa E402
 
+"""
 jediTaskID = 998
 ret = Client.getPandaIDsWithTaskID(jediTaskID, verbose=False)
 # print(ret)
@@ -21,6 +22,7 @@ ret = Client.getFullJobStatus(ids=jobids, verbose=False)
 
 ret = Client.getJediTaskDetails({'jediTaskID': jediTaskID}, True, True, verbose=False)
 print(ret)
+"""
 
 """
 jobids = []
@@ -39,9 +41,20 @@ start_time = start_time.strftime('%Y-%m-%d %H:%M:%S')
 # ret = Client.getJobIDsJediTasksInTimeRange(start_time, verbose=False)
 # print(ret)
 
-ret = Client.getJobIDsJediTasksInTimeRange(start_time, task_type='test', verbose=False)
-print(ret)
+# ret = Client.getJobIDsJediTasksInTimeRange(start_time, task_type='test', verbose=False)
+# print(ret)
 # ret = Client.getJobIDsJediTasksInTimeRange(start_time, dn='/DC=ch/DC=cern/OU=Organic Units/OU=Users/CN=atlpilo1/CN=614260/CN=Robot: ATLAS Pilot1', task_type='test', verbose=False)
 # print(ret)
 # ret = Client.getJobIDsJediTasksInTimeRange(start_time, dn='atlpilo1', task_type='test', verbose=False)
 # print(ret)
+
+
+taskID = 1365
+newOpts = {}
+# warning for PQ
+# site = newOpts.get('site', None)
+# excludedSite = newOpts.get('excludedSite', None)
+# for JEDI
+status, out = Client.retryTask(taskID, verbose=True, properErrorCode=True, newParams=newOpts)
+print(status)
+print(out)
